<?php

namespace Auth;

use Application;
use Client;
use Event\AuthEvent;
use Role;
use Symfony\Component\EventDispatcher\Event;
use Symfony\Component\HttpFoundation\RedirectResponse;

class RoleAuth
{
    /**
     * Function for register callback when we need check a role
     *
     * @param Event $event
     */
    public function register(AuthEvent $event)
    {
        $roles = (new Role())->get();
        $auth = $event->getAuth();

        foreach ($roles as $r) {
            $auth->register(
                $r['role_code'],
                function (Auth $auth, $roleName) {
                    return $this->handle($auth, $roleName);
                }
            );
        }
    }

    /**
     *
     * @param Auth   $auth
     * @param string $roleName
     *
     * @return bool|RedirectResponse
     */
    public function handle(Auth $auth, $roleName)
    {
        $request = $auth->getRequest();
        $redirect = ($request->get('redirect') != false) ? $request->get('redirect') : 'login';

        $clientId = $request->getSession()->get('client_id');

        if (!empty($clientId)) {
            $client = new Client($clientId);
            $hasRole = $client->hasRole($roleName);
        }

        if (empty($hasRole)) {
            return new RedirectResponse(
                Application::getRouter()->getRouter()->generate($redirect)
            );
        }

        return true;
    }

}